@@ -34,7 +34,7 @@ use parent 'LyricFinder::_Class';
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 our @FETCHERS = ();
 our $DEBUG = 0;  # If you want debug messages, set debug to a true value
 
@@ -352,7 +352,8 @@ object can be used for multiple fetches from multiple sites, so this
 normally only needs to be called once.
 
 I<options> is a hash of option/value pairs (ie. "-option" => "value").  
-The currently-supported options are:  
+If an "-option" is specified with no "value" given, the default value will 
+be I<1> ("I<true>").  The currently-supported options are:  
 
 =over 4
 
@@ -364,7 +365,7 @@ pass to the lyrics sites.  Some sites are pickey about receiving a user-agent
 string that corresponds to a valid / supported web-browser to prevent their 
 sites from being "scraped" by programs, such as this.
 
-Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:80.0) Gecko/20100101 Firefox/80.0">.
+Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:84.0) Gecko/20100101 Firefox/84.0">.
 
 NOTE:  This value will be overridden if $founder->agent("agent") is 
 called!  NOTE:  See below how to specify a different agent for a specific 
@@ -380,7 +381,7 @@ If no matching lyrics file is found (and the search module list is not
 specifically set to "Cache" (and lyrics are found on the internet), then 
 the lyrics will be saved to the directory under "I<artist>/I<title>.lrc".
 
-Default:  none (no caching)
+Default:  I<none> (no caching)
 
 An optional dirctional indicator ("<" or ">") can be prepended to the 
 directory to limit caching activity.  "<" allows fetching lyrics from the 
@@ -408,24 +409,31 @@ Specifies whether debug information will be displayed (0: no, >0: yes).
 Default I<0> (no).  I<1> will display debug info.  There is currently only 
 one level of debug verbosity.
 
-=item B<-nostatus> => I<0 | 1> (I<false> or I<true>)
+=item B<-noextra> => I<0 | 1> (I<false> or I<true>)
 
-If specified or given a I<true> value, sites may append some additional 
-information below the lyrics text.  Currently, only Musixmatch 
-(LyricFinder::Musixmatch) actually offers any additional information.  
-Default I<0> (false).
+Some sites (currently, only Musixmatch) may append some additional 
+information below the lyrics text.  If specified or given a I<true> value, 
+this will be suppressed and only the actual long lyrics returned.    
+Default I<0> (false) - show any additional site-specific information.
 
-=item B<site-module-name> => { I<"-option"> => I<value> [, I<"-option"> => I<value> ... ] }
+=item B<-site-module-name> => { I<"-option"> => I<value> [, I<"-option"> => I<value> ... ] }
 
-Specifies these same options for a specific site fetcher module.  These values 
+Specifies options for a specific site fetcher module.  These values 
 will override any of the general option values specified for that specific 
 module or calls to the general B<agent>() method, if it is used to fetch 
 lyrics.  Examples would be if one needed to specify a different user-agent 
 for one of the sites, or wished to cache lyrics fetched by sites to specific 
-directories for some reason.
+directories for some reason.  By default, top-level options are passed to 
+the various sites, so this should only be needed in special cases.
+
+Example:  "-Musixmatch => { -noextra => 1 }"
 
 Default:  none (no site-specific options)
 
+NOTE:  The "-cache" (cache-directory) option is needed by the main LyricFinder 
+module and the site submodules in order to use the caching feature, so passing 
+"-Cache => {-cache => I<directory>}" will NOT work (the way one might assume)!
+
 =back 
 
 =item [ I<$current-agent string> = ] $finder->B<agent>( [ I<user-agent string> ] )
