@@ -181,12 +181,13 @@ I<"Musixmatch"> as the third argument of the B<fetch>() method.
 
 NOTE:  Musixmatch flags lyrics with a status of either "ok", "warning", or 
 "error".  "warning" seems to mean "pending review", and when flagged "error", 
-their site says "We detected some issues".  I don't know if this means someone's 
-complained about correctness, profanity, etc.  Therefore, we append:  
-(Musixmatch status: I<status>) to the end of the returned lyrics.  This can be 
-suppressed by passing the option "-nostatus" => 1.  There are some 
-rare cases where no lyrics are found the normal way and we have to try a 
-backup method to extract them.  In those cases, we set the status 
+their site says "We detected some issues".  I don't know if this means 
+someone's complained about correctness, profanity, etc.  Therefore, we 
+append:  (Musixmatch status: I<status>) to the end of the returned lyrics.  
+
+This status msg. can be suppressed by passing the option "-noextra" => 1.  
+There are some rare cases where no lyrics are found the normal way and we 
+have to try a backup method to extract them.  In those cases, we set the status 
 to "error!".
 
 In case of problems with fetching lyrics, the error string will be returned by 
@@ -207,7 +208,8 @@ object can be used for multiple fetches, so this normally only needs to be
 called once.
 
 I<options> is a hash of option/value pairs (ie. "-option" => "value").  
-The currently-supported options are:  
+If an "-option" is specified with no "value" given, the default value will 
+be I<1> ("I<true>").  The currently-supported options are:  
 
 =over 4
 
@@ -219,7 +221,7 @@ pass to www.musixmatch.com.  Some sites are pickey about receiving a user-agent
 string that corresponds to a valid / supported web-browser to prevent their 
 sites from being "scraped" by programs, such as this.  
 
-Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:80.0) Gecko/20100101 Firefox/80.0">.
+Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:84.0) Gecko/20100101 Firefox/84.0">.
 
 NOTE:  This value will be overridden if $founder->agent("agent") is 
 called!
@@ -260,22 +262,25 @@ Specifies whether debug information will be displayed (0: no, >0: yes).
 Default I<0> (no).  I<1> will display debug info.  There is currently only 
 one level of debug verbosity.
 
-=item B<-nostatus> => I<0 | 1> (I<false> or I<true>)
+=item B<-noextra> => I<0 | 1> (I<false> or I<true>)
 
-If specified or given a I<true> value, the message containing the 
-Musixmatch "status" will not be appended below the lyrics text.
-Default I<0> (false).
+Musixmatch returns a (useful to some) "status" reflecting the quality or 
+"status" of the lyrics for each song on their site.  This message is appended 
+to the bottom of the lyrics returned.  If specified or given a I<true> value, 
+the message containing the Musixmatch "status" will NOT be appended below the 
+lyrics text and only the actual lyrics will be returned.  Default I<0> (false) 
+(append the message).
 
 =back 
 
 =item [ I<$current-agent string> = ] $finder->B<agent>( [ I<user-agent string> ] )
 
-Set the desired user-agent (ie. browser name) to pass to www.musixmatch.com.  
-Some sites are pickey about receiving a user-agent 
+Set / get the desired user-agent (ie. browser name) to pass to 
+www.musixmatch.com.  Some sites are pickey about receiving a user-agent 
 string that corresponds to a valid / supported web-browser to prevent their 
 sites from being "scraped" by programs, such as this.  
 
-Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:80.0) Gecko/20100101 Firefox/80.0">
+Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:84.0) Gecko/20100101 Firefox/84.0">
 
 If no argument is passed, it returns the current GENERAL user-agent string in 
 effect (but a different agent option is specified for a specific module may 
